==> com.careboo.unity-algorand-sdk-2.3.0-pre.4.tgz: package/Runtime/CareBoo.AlgoSdk.WalletConnect/Models/NetworkMessage.cs <==
using System;
using AlgoSdk;
using Unity.Collections;

namespace AlgoSdk.WalletConnect
{
    [AlgoApiObject]
    public partial struct NetworkMessage
        : IEquatable<NetworkMessage>
    {
        [AlgoApiField("topic", null)]
        public string Topic;

        [AlgoApiField("type", null)]
        public string Type;

        [AlgoApiField("payload", null)]
        public string Payload;

        [AlgoApiField("silent", null)]
        public Optional<bool> IsSilent;

        public bool Equals(NetworkMessage other)
        {
            return StringComparer.Equals(Topic, other.Topic)
                && StringComparer.Equals(Type, other.Type)
                && Payload.Equals(other.Payload)
                ;
        }

        public static NetworkMessage SubscribeToTopic(string topic)
        {
            return new NetworkMessage
            {
                Topic = topic,
                Type = "sub",
                Payload = ""
            };
        }

        public static NetworkMessage PublishToTopic<T>(T payload, string topic)
        {
            var payloadJson = AlgoApiSerializer.SerializeJson(payload);
            return new NetworkMessage
            {
                Topic = topic,
                Type = "pub",
                Payload = payloadJson
            };
        }

        public static NetworkMessage PublishToTopicEncrypted<T>(T payload, Hex encryptionKey, string topic)
        {
            using var payloadJson = AlgoApiSerializer.SerializeJson(payload, Allocator.Temp);
            var encryptedPayload = AesCipher.EncryptWithKey(encryptionKey, payloadJson.ToByteArray());
            return PublishToTopic(encryptedPayload, topic);
        }
    }
}

==> com.careboo.unity-algorand-sdk-3.0.0-pre.1.tgz: package/Runtime/CareBoo.AlgoSdk.WalletConnect/Models/NetworkMessage.cs <==
using System;
using AlgoSdk;
using Unity.Collections;

namespace AlgoSdk.WalletConnect
{
    [AlgoApiObject]
    public partial struct NetworkMessage
        : IEquatable<NetworkMessage>
    {
        [AlgoApiField("topic")]
        public string Topic;

        [AlgoApiField("type")]
        public string Type;

        [AlgoApiField("payload")]
        public string Payload;

        [AlgoApiField("silent")]
        public Optional<bool> IsSilent;

        public bool Equals(NetworkMessage other)
        {
            return StringComparer.Equals(Topic, other.Topic)
                && StringComparer.Equals(Type, other.Type)
                && Payload.Equals(other.Payload)
                ;
        }

        public static NetworkMessage SubscribeToTopic(string topic)
        {
            return new NetworkMessage
            {
                Topic = topic,
                Type = "sub",
                Payload = ""
            };
        }

        public static NetworkMessage PublishToTopic<T>(T payload, string topic)
        {
            var payloadJson = AlgoApiSerializer.SerializeJson(payload);
            return new NetworkMessage
            {
                Topic = topic,
                Type = "pub",
                Payload = payloadJson
            };
        }

        public static NetworkMessage PublishToTopicEncrypted<T>(T payload, Hex encryptionKey, string topic)
        {
            using var payloadJson = AlgoApiSerializer.SerializeJson(payload, Allocator.Temp);
            var encryptedPayload = AesCipher.EncryptWithKey(encryptionKey, payloadJson.ToByteArray());
            return PublishToTopic(encryptedPayload, topic);
        }
    }
}
